Changelog
=========


0.1.3 (released)
------------------

• Stable release + bug fixes [kelly].


0.0.0 (unreleased)
------------------

• Initial unreleased release [kelly].


.. Copyright © 2019–2020 California Institute of Technology ("Caltech").
   ALL RIGHTS RESERVED. U.S. Government sponsorship acknowledged.
